# [TARPIT](https://lazor.cn) [![Build Status](https://travis-ci.org/isatiso/tarpit.svg?branch=master)](https://travis-ci.org/isatiso/tarpit)[![PyPI version](https://badge.fury.io/py/tarpit.svg)](https://badge.fury.io/py/tarpit)

一个快速构建服务后台的库，可以快速创建简单后台。